local f = CreateFrame("Frame")

f:SetScript("OnEvent", function(self, event, ...)
	self[event](self, event, ...)
end)
f:RegisterEvent("ADDON_LOADED")

local pom_name = GetSpellInfo(41635)
local UnitAura = UnitAura
local name, rank, icon, count, debuffType, duration, expirationTime, caster, isStealable
local GridStatus = Grid:GetModule("GridStatus")
local GridRoster = Grid:GetModule("GridRoster")

function f.ADDON_LOADED(self,event,arg1)
    if arg1 == "GridMending" then
        GridMendingDB = GridMendingDB or {}
        GridMendingDB.selfonly = GridMendingDB.selfonly or false
        GridMendingDB.colors = GridMendingDB.colors or {
            [1] = { a = 1, r = 0.91, g = 1, b = 0.6 },
            [2] = { a = 1, r = 1, g = 0.6, b = 0.47 },
            [3] = { a = 1, r = 1, g = 0.4, b = 0.52 },
            [4] = { a = 1, r = 1, g = 0.37, b = 0.83},
            [5] = { a = 1, r = 0.53, g = 0.06, b = 1},
            [6] = { a = 1, r = 0.26, g = 0.22, b = 1},
            ["alien"] = { a = 1, r = 0.45, g = 0.75, b = 1},
        }
    end
end




local function OnInitialize(self)
	self.super.OnInitialize(self)
    local PoMoptions = {
    {
        type = 'toggle',
        name = "Show own spell only",
--~         desc = "",
        get = function()
            return GridMendingDB.selfonly
        end,
        set = function(v)
            GridMendingDB.selfonly = v
        end,
        map = { [false] = "Disabled", [true] = "Enabled" }
    },
    {
		type = "color",
		name = "6 (only with set bonus)",
		desc = "6 charges color",
        hasAlpha = true,
        get = function ()
                    local s = GridMendingDB.colors[6]
                    return s.r, s.g, s.b, s.a
		      end,
		set = function (r, g, b, a)
                    local s = GridMendingDB.colors[6]
                    s.r, s.g, s.b, s.a = r, g, b, a or 1;
		      end,
	},
    {
		type = "color",
		name = "Other priests",
--~ 		desc = "6 charges color",
        hasAlpha = true,
        get = function ()
                    local s = GridMendingDB.colors["alien"]
                    return s.r, s.g, s.b, s.a
		      end,
		set = function (r, g, b, a)
                    local s = GridMendingDB.colors["alien"]
                    s.r, s.g, s.b, s.a = r, g, b, a or 1;
		      end,
	},
	{
		type = "color",
		name = "5",
		desc = "5 charges color",
        hasAlpha = true,
        get = function ()
                    local s = GridMendingDB.colors[5]
                    return s.r, s.g, s.b, s.a
		      end,
		set = function (r, g, b, a)
                    local s = GridMendingDB.colors[5]
                    s.r, s.g, s.b, s.a = r, g, b, a or 1;
		      end,
	},
    {
		type = "color",
		name = "4",
		desc = "4 charges color",
        hasAlpha = true,
        get = function ()
                    local s = GridMendingDB.colors[4]
                    return s.r, s.g, s.b, s.a
		      end,
		set = function (r, g, b, a)
                    local s = GridMendingDB.colors[4]
                    s.r, s.g, s.b, s.a = r, g, b, a or 1;
		      end,
	},
    {
		type = "color",
		name = "3",
		desc = "3 charges color",
        hasAlpha = true,
        get = function ()
                    local s = GridMendingDB.colors[3]
                    return s.r, s.g, s.b, s.a
		      end,
		set = function (r, g, b, a)
                    local s = GridMendingDB.colors[3]
                    s.r, s.g, s.b, s.a = r, g, b, a or 1;
		      end,
	},
    {
		type = "color",
		name = "2",
		desc = "2 charges color",
        hasAlpha = true,
        get = function ()
                    local s = GridMendingDB.colors[2]
                    return s.r, s.g, s.b, s.a
		      end,
		set = function (r, g, b, a)
                    local s = GridMendingDB.colors[2]
                    s.r, s.g, s.b, s.a = r, g, b, a or 1;
		      end,
	},
    {
		type = "color",
		name = "1",
		desc = "1 charges color",
        hasAlpha = true,
        get = function ()
                    local s = GridMendingDB.colors[1]
                    return s.r, s.g, s.b, s.a
		      end,
		set = function (r, g, b, a)
                    local s = GridMendingDB.colors[1]
                    s.r, s.g, s.b, s.a = r, g, b, a or 1;
		      end,
	},
}
	self:RegisterStatus("alert_pom", pom_name, PoMoptions, true)
end

local function OnEnable(self)
    self:RegisterEvent("UNIT_AURA", "UnitAuraChanged")
end

local function UnitAuraChanged(self, unit)
    local guid = UnitGUID(unit)
	if not GridRoster:IsGUIDInRaid(guid) then
		return
	end
    name, rank, icon, count, debuffType, duration, expirationTime, caster, isStealable = UnitAura(unit, pom_name, nil, "HELPFUL")
    
    if not name then
		self.core:SendStatusLost(guid, "alert_pom")
        return
    end
    
    if count then
        local settings = self.db.profile.alert_pom
        local color
        if caster == "player" then
            color = GridMendingDB.colors[count]
        elseif not GridMendingDB.selfonly then
            color = GridMendingDB.colors["alien"]
        end
        self.core:SendStatusGained(guid, "alert_pom", settings.priority, (settings.range and 40), color, "PoM:"..count, count, nil, icon, expirationTime - duration, duration, count)
	end
end


        local GridMending = GridStatus:NewModule("GridMending")
        GridMending.menuName = pom_name
        GridMending.options = true
        GridMending.defaultDB = {
            alert_pom = {
                text = pom_name,
                enable = true,
                color = { r = 0, g = 0, b = 0, a = 1 },
                priority = 90,
                range = true,
            },
        }
        
        GridMending.OnInitialize = OnInitialize
        GridMending.OnEnable = OnEnable
        GridMending.UnitAuraChanged = UnitAuraChanged